==> babel-preset-jam-0.1.1.tgz: package/README.md <==
# babel-preset-jam

[![GitHub stars](https://img.shields.io/github/stars/codejamninja/babel-preset-jam.svg?style=social&label=Stars)](https://github.com/codejamninja/babel-preset-jam)

> all official proposed plugins for babel 7

Please ★ this repo if you found it useful ★ ★ ★


## Features

* babel-preset-jam


## Installation

```sh
npm install --save-dev babel-preset-jam
```


## Dependencies

* [NodeJS](https://nodejs.org)
* [Babel 7](https://babeljs.io)


## Usage

[Contribute](https://github.com/codejamninja/babel-preset-jam/blob/master/CONTRIBUTING.md) usage docs


## Support

Submit an [issue](https://github.com/codejamninja/babel-preset-jam/issues/new)


## Screenshots

[Contribute](https://github.com/codejamninja/babel-preset-jam/blob/master/CONTRIBUTING.md) a screenshot


## Contributing

Review the [guidelines for contributing](https://github.com/codejamninja/babel-preset-jam/blob/master/CONTRIBUTING.md)


## License

[MIT License](https://github.com/codejamninja/babel-preset-jam/blob/master/LICENSE)

[Jam Risser](https://codejam.ninja) © 2018


## Changelog

Review the [changelog](https://github.com/codejamninja/babel-preset-jam/blob/master/CHANGELOG.md)


## Credits

* [Jam Risser](https://codejam.ninja) - Author


## Support on Liberapay

A ridiculous amount of coffee ☕ ☕ ☕ was consumed in the process of building this project.

[Add some fuel](https://liberapay.com/codejamninja/donate) if you'd like to keep me going!

[![Liberapay receiving](https://img.shields.io/liberapay/receives/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)
[![Liberapay patrons](https://img.shields.io/liberapay/patrons/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)

==> babel-preset-jam-0.4.1.tgz: package/README.md <==
# babel-preset-jam

[![GitHub stars](https://img.shields.io/github/stars/codejamninja/babel-preset-jam.svg?style=social&label=Stars)](https://github.com/codejamninja/babel-preset-jam)

> all official proposed plugins for babel 7

Please ★ this repo if you found it useful ★ ★ ★

## Features

- babel-preset-jam

## Installation

```sh
npm install --save-dev babel-preset-jam
```

## Dependencies

- [NodeJS](https://nodejs.org)
- [Babel 7](https://babeljs.io)

## Usage

[Contribute](https://github.com/codejamninja/babel-preset-jam/blob/master/CONTRIBUTING.md) usage docs

## Support

Submit an [issue](https://github.com/codejamninja/babel-preset-jam/issues/new)

## Screenshots

[Contribute](https://github.com/codejamninja/babel-preset-jam/blob/master/CONTRIBUTING.md) a screenshot

## Contributing

Review the [guidelines for contributing](https://github.com/codejamninja/babel-preset-jam/blob/master/CONTRIBUTING.md)

## License

[MIT License](https://github.com/codejamninja/babel-preset-jam/blob/master/LICENSE)

[Jam Risser](https://codejam.ninja) © 2018

## Changelog

Review the [changelog](https://github.com/codejamninja/babel-preset-jam/blob/master/CHANGELOG.md)

## Credits

- [Jam Risser](https://codejam.ninja) - Author

## Support on Liberapay

A ridiculous amount of coffee ☕ ☕ ☕ was consumed in the process of building this project.

[Add some fuel](https://liberapay.com/codejamninja/donate) if you'd like to keep me going!

[![Liberapay receiving](https://img.shields.io/liberapay/receives/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)
[![Liberapay patrons](https://img.shields.io/liberapay/patrons/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)
